Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2559)

Unified Diff: chrome/test/data/push_messaging/push_test.js

Issue 2487233002: Handle push resubscribes with no sender info (avoids DCHECK) (Closed)
Patch Set: Handle push resubscribes with no sender info (avoids DCHECK) Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/test/data/push_messaging/push_test.js
diff --git a/chrome/test/data/push_messaging/push_test.js b/chrome/test/data/push_messaging/push_test.js
index 9a1336067db956d91f95e0205b977dca81d08427..212b57a1767e07c0fd95609fec579f9e288ba005 100644
--- a/chrome/test/data/push_messaging/push_test.js
+++ b/chrome/test/data/push_messaging/push_test.js
@@ -125,6 +125,18 @@ function documentSubscribePushBadKey() {
}).catch(sendErrorToTest);
}
+function documentSubscribePushWithNumericKey() {
+ navigator.serviceWorker.ready.then(function(swRegistration) {
+ return swRegistration.pushManager.subscribe({
+ userVisibleOnly: true,
+ applicationServerKey: new TextEncoder().encode('1234567890')
+ })
+ .then(function(subscription) {
+ sendResultToTest(subscription.endpoint);
+ });
+ }).catch(sendErrorToTest);
+}
+
function workerSubscribePush() {
// Send the message to the worker for it to subscribe
navigator.serviceWorker.controller.postMessage({command: 'workerSubscribe'});
@@ -132,11 +144,18 @@ function workerSubscribePush() {
function workerSubscribePushNoKey() {
// The worker will try to subscribe without providing a key. This should
// succeed if the worker was previously subscribed and fail otherwise.
navigator.serviceWorker.controller.postMessage(
{command: 'workerSubscribeNoKey'});
}
+function workerSubscribePushWithNumericKey() {
+ // Send the message to the worker for it to subscribe
+ navigator.serviceWorker.controller.postMessage(
+ {command: 'workerSubscribeWithNumericKey'});
+}
+
function GetP256dh() {
navigator.serviceWorker.ready.then(function(swRegistration) {
return swRegistration.pushManager.getSubscription()
@@ -132,11 +144,18 @@ function workerSubscribePush() {
function workerSubscribePushNoKey() {
// The worker will try to subscribe without providing a key. This should
- // succeed if the worker was previously subscribed and fail otherwise.
+ // succeed if the worker was previously subscribed with a numeric key
+ // and fail otherwise.
navigator.serviceWorker.controller.postMessage(
{command: 'workerSubscribeNoKey'});
« no previous file with comments | « chrome/browser/push_messaging/push_messaging_browsertest.cc ('k') | chrome/test/data/push_messaging/service_worker.js » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698